DjangoElementType

Enum DjangoElementType 

pub enum DjangoElementType {
Show 58 variants Root, Identifier, Variable, Tag, Comment, HtmlContent, If, Elif, Else, Endif, For, Empty, Endfor, Block, Endblock, Extends, Include, Load, With, Endwith, Autoescape, Endautoescape, Csrf, Url, Static, Now, Cycle, Filter, Endfilter, Spaceless, Endspaceless, Verbatim, Endverbatim, And, Or, Not, In, Plus, Minus, Star, Slash, LeftParen, RightParen, LeftBracket, RightBracket, Semicolon, Dot, Comma, Equal, IfStatement, ForStatement, BlockStatement, FilterExpression, BinaryExpression, Literal, Whitespace, Newline, Error,
}
Element types for Django templates.

Variants



Root

The root element.



Identifier

An identifier.



Variable

A variable expression: {{ ... }}.



Tag

A tag: {% ... %}.



Comment

A comment: {# ... #}.



HtmlContent

Plain HTML content.



If

if keyword.



Elif

elif keyword.



Else

else keyword.



Endif

endif keyword.



For

for keyword.



Empty

empty keyword.



Endfor

endfor keyword.



Block

block keyword.



Endblock

endblock keyword.



Extends

extends keyword.



Include

include keyword.



Load

load keyword.



With

with keyword.



Endwith

endwith keyword.



Autoescape

autoescape keyword.



Endautoescape

endautoescape keyword.



Csrf

csrf_token keyword.



Url

url keyword.



Static

static keyword.



Now

now keyword.



Cycle

cycle keyword.



Filter

filter keyword.



Endfilter

endfilter keyword.



Spaceless

spaceless keyword.



Endspaceless

endspaceless keyword.



Verbatim

verbatim keyword.



Endverbatim

endverbatim keyword.



And

and operator.



Or

or operator.



Not

not operator.



In

in operator.



Plus

+.



Minus

-.



Star

*.



Slash

/.



LeftParen

(.



RightParen

).



LeftBracket

[.



RightBracket

].



Semicolon

;.



Dot

..



Comma

,.



Equal

=.



IfStatement

If statement node.



ForStatement

For statement node.



BlockStatement

Block statement node.



FilterExpression

Filter expression node.



BinaryExpression

Binary expression node.



Literal

Literal node.



Whitespace

Whitespace.



Newline

Newline.



Error

Error token.

Implementations

Source

impl DjangoElementType

pub fn is_keyword(&self) -> bool

Returns true if the element type is a keyword.

pub fn is_trivia(&self) -> bool

Returns true if the element type is trivia (whitespace, newline, or comment).